==> ethereal-0.10.5.tar.bz2: ethereal-0.10.5/gtk/rtp_analysis.h <==
/* rtp_analysis.h
 * RTP analysis addition for ethereal
 *
 * $Id: rtp_analysis.h,v 1.2 2004/06/02 22:13:04 ulfl Exp $
 *
 * Copyright 2003, Alcatel Business Systems
 * By Lars Ruoff <lars.ruoff@gmx.net>
 *
 * based on tap_rtp.c
 * Copyright 2003, Iskratel, Ltd, Kranj
 * By Miha Jemec <m.jemec@iskratel.si>
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@ethereal.com>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation,  Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef RTP_ANALYSIS_H_INCLUDED
#define RTP_ANALYSIS_H_INCLUDED

#include <glib.h>

/** @file
 *  ??? 
 *  @todo what's this?
 */

void rtp_analysis(
		guint32 ip_src_fwd,  /* network-order IPv4 address */
		guint16 port_src_fwd,
		guint32 ip_dst_fwd,  /* network-order IPv4 address */
		guint16 port_dst_fwd,
		guint32 ssrc_fwd,
		guint32 ip_src_rev,  /* network-order IPv4 address */
		guint16 port_src_rev,
		guint32 ip_dst_rev,  /* network-order IPv4 address */
		guint16 port_dst_rev,
		guint32 ssrc_rev
		);

#endif /*RTP_ANALYSIS_H_INCLUDED*/

==> ethereal-0.10.9.tar.bz2: ethereal-0.10.9/gtk/rtp_analysis.h <==
/* rtp_analysis.h
 * RTP analysis addition for ethereal
 *
 * $Id: rtp_analysis.h 12636 2004-12-01 11:54:41Z guy $
 *
 * Copyright 2003, Alcatel Business Systems
 * By Lars Ruoff <lars.ruoff@gmx.net>
 *
 * based on tap_rtp.c
 * Copyright 2003, Iskratel, Ltd, Kranj
 * By Miha Jemec <m.jemec@iskratel.si>
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@ethereal.com>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation,  Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef RTP_ANALYSIS_H_INCLUDED
#define RTP_ANALYSIS_H_INCLUDED

#include <glib.h>
#include <epan/address.h>

/** @file
 *  ??? 
 *  @todo what's this?
 */

void rtp_analysis(
		address *ip_src_fwd,
		guint16 port_src_fwd,
		address *ip_dst_fwd,
		guint16 port_dst_fwd,
		guint32 ssrc_fwd,
		address *ip_src_rev,
		guint16 port_src_rev,
		address *ip_dst_rev,
		guint16 port_dst_rev,
		guint32 ssrc_rev
		);


#endif /*RTP_ANALYSIS_H_INCLUDED*/
